<?php
/**
 * @file
 * commerce_canadian_taxes.rules_defaults.inc - Defines the default tax rules for Commerce Canadian Taxes.

 */

// When referencing rule component, need to prefix their names with "component_"
define("COMPONENT_NAME_PREFIX", "component_");


/**
 * Implements hook_default_rules_configuration().
 *
 * Rule components for Commerce Canadian Taxes: HST, GST, and PST.
 *
 * Current as at 1 April 2013, including conversion to HST for PE and reversion to GST/PST for BC.
 *
 * Notes:
 *  - Rule labels for components are based on the naming method used in Drupal Commerce:
 *    @code
 *      $rule->label = t('Calculate @title', array('@title' => $tax_rate['title']));
 *    @endcode
 *
 * @todo:
 *  Only the general PST rates are currently defined; for example, some provinces apply a different rate for sale of alcohol.
 */
function commerce_canadian_taxes_default_rules_configuration() {

  $rules = array();

  $component_variable = array(
    'line_item' => array(
      'label' => t('Line item'),
      'type' => 'commerce_line_item',
    ),
  );

  //
  // Need a component for each tax field checkbox - organize by jurisdiction (NL, NS, PE, ..., NU)
  //

  // NL - Apply HST
  // Condition: Product field "Apply HST NL" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply HST NL');
  $rule->tags = array('Commerce Canadian Taxes', 'HST', 'NL');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_nl'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-nl', 'field' => 'field_apply_ca_hst'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-nl:field-apply-ca-hst', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_nl'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-nl', 'field' => 'field_apply_ca_hst'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-nl:field-apply-ca-hst', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_nl_hst'] = $rule;

  // NL - Apply RST
  // Condition: Product field "Apply RST NL" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply RST NL');
  $rule->tags = array('Commerce Canadian Taxes', 'RST', 'PVT', 'NL', 'Provincial Vehicle Tax');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_nl'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-nl', 'field' => 'field_apply_ca_pvt'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-nl:field-apply-ca-pvt', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_nl'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-nl', 'field' => 'field_apply_ca_pvt'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-nl:field-apply-ca-pvt', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_nl_pvt'] = $rule;

  // Condition: Product field "Apply HST NS" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply HST NS');
  $rule->tags = array('Commerce Canadian Taxes', 'HST', 'NS');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_ns'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-ns', 'field' => 'field_apply_ca_hst'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-ns:field-apply-ca-hst', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_ns'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-ns', 'field' => 'field_apply_ca_hst'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-ns:field-apply-ca-hst', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_ns_hst'] = $rule;

  // Condition: Product field "Apply HST PE" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply HST PE');
  $rule->tags = array('Commerce Canadian Taxes', 'HST', 'PE');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_pe'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-pe', 'field' => 'field_apply_ca_hst'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-pe:field-apply-ca-hst', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_pe'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-pe', 'field' => 'field_apply_ca_hst'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-pe:field-apply-ca-hst', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_pe_hst'] = $rule;

  // Condition: Product field "Apply HST NB" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply HST NB');
  $rule->tags = array('Commerce Canadian Taxes', 'HST', 'NB');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_nb'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-nb', 'field' => 'field_apply_ca_hst'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-nb:field-apply-ca-hst', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_nb'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-nb', 'field' => 'field_apply_ca_hst'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-nb:field-apply-ca-hst', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_nb_hst'] = $rule;

  // Condition: Product field "Apply PVT NB" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply PVT NB');
  $rule->tags = array('Commerce Canadian Taxes', 'PVT', 'NB', 'Provincial Vehicle Tax');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_nb'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-nb', 'field' => 'field_apply_ca_pvt'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-nb:field-apply-ca-pvt', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_nb'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-nb', 'field' => 'field_apply_ca_pvt'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-nb:field-apply-ca-pvt', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_nb_pvt'] = $rule;

  // Condition: Product field "Apply TPPT NB" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply TPPT NB');
  $rule->tags = array('Commerce Canadian Taxes', 'TPPT', 'NB', 'Tangible Personal Property Tax');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_nb'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-nb', 'field' => 'field_apply_ca_nb_tppt'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-nb:field-apply-ca-nb_tppt', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_nb'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-nb', 'field' => 'field_apply_ca_nb_tppt'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-nb:field-apply-ca-nb_tppt', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_nb_tppt'] = $rule;

  // Condition: Product field "Apply GST QC" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply GST QC');
  $rule->tags = array('Commerce Canadian Taxes', 'GST', 'QC');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_qc'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-qc', 'field' => 'field_apply_ca_gst'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-qc:field-apply-ca-gst', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_qc'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-qc', 'field' => 'field_apply_ca_gst'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-qc:field-apply-ca-gst', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_qc_gst'] = $rule;

  // Condition: Product field "Apply QST QC" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply QST QC');
  $rule->tags = array('Commerce Canadian Taxes', 'PST', 'QST', 'QC');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_qc'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-qc', 'field' => 'field_apply_ca_pst'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-qc:field-apply-ca-pst', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_qc'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-qc', 'field' => 'field_apply_ca_pst'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-qc:field-apply-ca-pst', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_qc_pst'] = $rule;

  // Condition: Product field "Apply HST ON" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply HST ON');
  $rule->tags = array('Commerce Canadian Taxes', 'HST', 'ON');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_on'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-on', 'field' => 'field_apply_ca_hst'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-on:field-apply-ca-hst', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_on'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-on', 'field' => 'field_apply_ca_hst'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-on:field-apply-ca-hst', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_on_hst'] = $rule;

  // Condition: Product field "Apply GST ON" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply GST ON');
  $rule->tags = array('Commerce Canadian Taxes', 'GST', 'ON');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_on'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-on', 'field' => 'field_apply_ca_gst'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-on:field-apply-ca-gst', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_on'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-on', 'field' => 'field_apply_ca_gst'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-on:field-apply-ca-gst', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_on_gst'] = $rule;

  // Condition: Product field "Apply GST MB" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply GST MB');
  $rule->tags = array('Commerce Canadian Taxes', 'GST', 'MB');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_mb'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-mb', 'field' => 'field_apply_ca_gst'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-mb:field-apply-ca-gst', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_mb'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-mb', 'field' => 'field_apply_ca_gst'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-mb:field-apply-ca-gst', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_mb_gst'] = $rule;

  // Condition: Product field "Apply RST MB" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply RST MB');
  $rule->tags = array('Commerce Canadian Taxes', 'PST', 'RST', 'MB');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_mb'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-mb', 'field' => 'field_apply_ca_pst'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-mb:field-apply-ca-pst', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_mb'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-mb', 'field' => 'field_apply_ca_pst'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-mb:field-apply-ca-pst', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_mb_pst'] = $rule;

  // Condition: Product field "Apply PVT MB" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply PVT MB');
  $rule->tags = array('Commerce Canadian Taxes', 'PVT', 'MB', 'Provincial Vehicle Tax');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_mb'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-mb', 'field' => 'field_apply_ca_pvt'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-mb:field-apply-ca-pvt', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_mb'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-mb', 'field' => 'field_apply_ca_pvt'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-mb:field-apply-ca-pvt', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_mb_pvt'] = $rule;

  // Condition: Product field "Apply GST SK" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply GST SK');
  $rule->tags = array('Commerce Canadian Taxes', 'GST', 'SK');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_sk'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-sk', 'field' => 'field_apply_ca_gst'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-sk:field-apply-ca-gst', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_sk'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-sk', 'field' => 'field_apply_ca_gst'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-sk:field-apply-ca-gst', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_sk_gst'] = $rule;

  // Condition: Product field "Apply PST SK" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply PST SK');
  $rule->tags = array('Commerce Canadian Taxes', 'PST', 'SK');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_sk'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-sk', 'field' => 'field_apply_ca_pst'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-sk:field-apply-ca-pst', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_sk'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-sk', 'field' => 'field_apply_ca_pst'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-sk:field-apply-ca-pst', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_sk_pst'] = $rule;

  // Condition: Product field "Apply LCT SK" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply LCT SK');
  $rule->tags = array('Commerce Canadian Taxes', 'LCT', 'SK', 'Liquor Consumption Tax');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_sk'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-sk', 'field' => 'field_apply_ca_plt'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-sk:field-apply-ca-plt', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_sk'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-sk', 'field' => 'field_apply_ca_plt'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-sk:field-apply-ca-plt', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_sk_plt'] = $rule;

  // Condition: Product field "Apply GST AB" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply GST AB');
  $rule->tags = array('Commerce Canadian Taxes', 'GST', 'AB');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_ab'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-ab', 'field' => 'field_apply_ca_gst'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-ab:field-apply-ca-gst', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_ab'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-ab', 'field' => 'field_apply_ca_gst'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-ab:field-apply-ca-gst', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_ab_gst'] = $rule;

  // Condition: Product field "Apply GST BC" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply GST BC');
  $rule->tags = array('Commerce Canadian Taxes', 'GST', 'BC');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_bc'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-bc', 'field' => 'field_apply_ca_gst'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-bc:field-apply-ca-gst', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_bc'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-bc', 'field' => 'field_apply_ca_gst'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-bc:field-apply-ca-gst', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_bc_gst'] = $rule;

  // Condition: Product field "Apply PST BC" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply PST BC');
  $rule->tags = array('Commerce Canadian Taxes', 'PST', 'BC');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_bc'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-bc', 'field' => 'field_apply_ca_pst'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-bc:field-apply-ca-pst', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_bc'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-bc', 'field' => 'field_apply_ca_pst'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-bc:field-apply-ca-pst', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_bc_pst'] = $rule;

  // Condition: Product field "Apply GST YT" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply GST YT');
  $rule->tags = array('Commerce Canadian Taxes', 'GST', 'YT');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_yt'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-yt', 'field' => 'field_apply_ca_gst'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-yt:field-apply-ca-gst', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_yt'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-yt', 'field' => 'field_apply_ca_gst'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-yt:field-apply-ca-gst', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_yt_gst'] = $rule;

  // Condition: Product field "Apply GST NT" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply GST NT');
  $rule->tags = array('Commerce Canadian Taxes', 'GST', 'NT');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_nt'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-nt', 'field' => 'field_apply_ca_gst'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-nt:field-apply-ca-gst', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_nt'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-nt', 'field' => 'field_apply_ca_gst'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-nt:field-apply-ca-gst', 'value' => 1))
            )
      );
  $rules['rule_apply_ca_nt_gst'] = $rule;

  // Condition: Product field "Apply GST NU" is set
  $rule = rules_and($component_variable);
  $rule->label = t('Apply GST NU');
  $rule->tags = array('Commerce Canadian Taxes', 'GST', 'NU');
  $rule->condition(
      rules_or()
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'commerce_product'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_nu'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-nu', 'field' => 'field_apply_ca_gst'))
              ->condition('data_is', array('data:select' => 'line-item:commerce-product:field-sales-taxes-ca:field-sales-taxes-ca-nu:field-apply-ca-gst', 'value' => 1))
            )
        ->condition(
            rules_and()
              ->condition('entity_has_field', array('entity:select' => 'line-item', 'field' => 'field_sales_taxes_ca'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca', 'field' => 'field_sales_taxes_ca_nu'))
              ->condition('entity_has_field', array('entity:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-nu', 'field' => 'field_apply_ca_gst'))
              ->condition('data_is', array('data:select' => 'line-item:field-sales-taxes-ca:field-sales-taxes-ca-nu:field-apply-ca-gst', 'value' => 1))
            )
      );

  $rules['rule_apply_ca_nu_gst'] = $rule;

  //----------------
  // Rule Components
  //----------------

  $component_variable = array(
    'commerce_line_item' => array(
      'label' => t('Line item'),
      'type' => 'commerce_line_item',
    ),
  );

  // Rule component to calculate GST for QC, ON, MB, SK, AB, BC, YT, NT, NU
  $rule = rule($component_variable);
  $rule->label = t('Calculate GST CA');
  $rule->tags = array('Commerce Canadian Taxes', 'GST', 'CA');
  $rule->weight = 10;
  $rule->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'country',
                                                            'value' => 'CA', ))
       ->condition(rules_or()
          ->condition(rules_and()
            ->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_qc_gst', array('line_item:select' => 'commerce-line-item'))
            ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                              'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                              'address_component' => 'administrative_area',
                                                              'value' => 'QC', ))
                        )
          ->condition(rules_and()
            ->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_on_gst', array('line_item:select' => 'commerce-line-item'))
            ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                              'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                              'address_component' => 'administrative_area',
                                                              'value' => 'ON', ))
                        )
          ->condition(rules_and()
            ->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_mb_gst', array('line_item:select' => 'commerce-line-item'))
            ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                              'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                              'address_component' => 'administrative_area',
                                                              'value' => 'MB', ))
                        )
          ->condition(rules_and()
            ->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_sk_gst', array('line_item:select' => 'commerce-line-item'))
            ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                              'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                              'address_component' => 'administrative_area',
                                                              'value' => 'SK', ))
                        )
          ->condition(rules_and()
            ->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_ab_gst', array('line_item:select' => 'commerce-line-item'))
            ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                              'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                              'address_component' => 'administrative_area',
                                                              'value' => 'AB', ))
                        )
          ->condition(rules_and()
            ->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_bc_gst', array('line_item:select' => 'commerce-line-item'))
            ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                              'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                              'address_component' => 'administrative_area',
                                                              'value' => 'BC', ))
                        )
          ->condition(rules_and()
            ->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_yt_gst', array('line_item:select' => 'commerce-line-item'))
            ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                              'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                              'address_component' => 'administrative_area',
                                                              'value' => 'YT', ))
                        )
          ->condition(rules_and()
            ->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_nt_gst', array('line_item:select' => 'commerce-line-item'))
            ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                              'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                              'address_component' => 'administrative_area',
                                                              'value' => 'NT', ))
                        )
          ->condition(rules_and()
            ->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_nu_gst', array('line_item:select' => 'commerce-line-item'))
            ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                              'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                              'address_component' => 'administrative_area',
                                                              'value' => 'NU', ))
                        )
                  )
       ->action('commerce_tax_rate_apply', array(
          'commerce_line_item:select' => 'commerce-line-item',
          'tax_rate_name' => 'ca_gst'
        ))
        ;
  $rules['commerce_tax_rate_calculate_ca_gst'] = $rule;

  // Rule component to calculate HST for NL
  $rule = rule($component_variable);
  $rule->label = t('Calculate HST NL');
  $rule->tags = array('Commerce Canadian Taxes', 'HST', 'NL');
  $rule->weight = 1;
  $rule->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_nl_hst', array('line_item:select' => 'commerce-line-item'))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'country',
                                                            'value' => 'CA', ))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'administrative_area',
                                                            'value' => 'NL', ))
       ->action('commerce_tax_rate_apply', array(
          'commerce_line_item:select' => 'commerce-line-item',
          'tax_rate_name' => 'ca_nl_hst',
        ))
        ;
  $rules['commerce_tax_rate_calculate_ca_nl_hst'] = $rule;

  // RST rule component to calculate RST for NL
  $rule = rule($component_variable);
  $rule->label = t('Calculate RST NL');
  $rule->tags = array('Commerce Canadian Taxes', 'RST', 'PVT', 'NL', 'Provincial Vehicle Tax');
  $rule->weight = 1;
  $rule->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_nl_pvt', array('line_item:select' => 'commerce-line-item'))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'country',
                                                            'value' => 'CA', ))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'administrative_area',
                                                            'value' => 'NL', ))
       ->action('commerce_tax_rate_apply', array(
          'commerce_line_item:select' => 'commerce-line-item',
          'tax_rate_name' => 'ca_nl_pvt',
        ))
        ;
  $rules['commerce_tax_rate_calculate_ca_nl_pvt'] = $rule;

  // Rule component to calculate HST for NS
  $rule = rule($component_variable);
  $rule->label = t('Calculate HST NS');
  $rule->tags = array('Commerce Canadian Taxes', 'HST', 'NS');
  $rule->weight = 1;
  $rule->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_ns_hst', array('line_item:select' => 'commerce-line-item'))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'country',
                                                            'value' => 'CA', ))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'administrative_area',
                                                            'value' => 'NS', ))
       ->action('commerce_tax_rate_apply', array(
          'commerce_line_item:select' => 'commerce-line-item',
          'tax_rate_name' => 'ca_ns_hst',
        ))
        ;
  $rules['commerce_tax_rate_calculate_ca_ns_hst'] = $rule;

  // Rule component to calculate HST for PE
  $rule = rule($component_variable);
  $rule->label = t('Calculate HST PE');
  $rule->tags = array('Commerce Canadian Taxes', 'HST', 'PE');
  $rule->weight = 1;
  $rule->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_pe_hst', array('line_item:select' => 'commerce-line-item'))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'country',
                                                            'value' => 'CA', ))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'administrative_area',
                                                            'value' => 'PE', ))
       ->action('commerce_tax_rate_apply', array(
          'commerce_line_item:select' => 'commerce-line-item',
          'tax_rate_name' => 'ca_pe_hst',
        ))
        ;
  $rules['commerce_tax_rate_calculate_ca_pe_hst'] = $rule;

  // Rule component to calculate HST for NB
  $rule = rule($component_variable);
  $rule->label = t('Calculate HST NB');
  $rule->tags = array('Commerce Canadian Taxes', 'HST', 'NB');
  $rule->weight = 1;
  $rule->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_nb_hst', array('line_item:select' => 'commerce-line-item'))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'country',
                                                            'value' => 'CA', ))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'administrative_area',
                                                            'value' => 'NB', ))
       ->action('commerce_tax_rate_apply', array(
          'commerce_line_item:select' => 'commerce-line-item',
          'tax_rate_name' => 'ca_nb_hst',
        ))
        ;
  $rules['commerce_tax_rate_calculate_ca_nb_hst'] = $rule;

  // Rule component to calculate PVT for NB
  $rule = rule($component_variable);
  $rule->label = t('Calculate PVT NB');
  $rule->tags = array('Commerce Canadian Taxes', 'PVT', 'NB', 'Provincial Vehicle Tax');
  $rule->weight = 1;
  $rule->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_nb_pvt', array('line_item:select' => 'commerce-line-item'))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'country',
                                                            'value' => 'CA', ))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'administrative_area',
                                                            'value' => 'NB', ))
       ->action('commerce_tax_rate_apply', array(
          'commerce_line_item:select' => 'commerce-line-item',
          'tax_rate_name' => 'ca_nb_pvt',
        ))
        ;
  $rules['commerce_tax_rate_calculate_ca_nb_pvt'] = $rule;

  // Rule component to calculate TPPT for NB
  $rule = rule($component_variable);
  $rule->label = t('Calculate TPPT NB');
  $rule->tags = array('Commerce Canadian Taxes', 'TPPT', 'NB', 'Tangible Personal Property Tax');
  $rule->weight = 1;
  $rule->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_nb_tppt', array('line_item:select' => 'commerce-line-item'))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'country',
                                                            'value' => 'CA', ))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'administrative_area',
                                                            'value' => 'NB', ))
       ->action('commerce_tax_rate_apply', array(
          'commerce_line_item:select' => 'commerce-line-item',
          'tax_rate_name' => 'ca_nb_tppt',
        ))
        ;
  $rules['commerce_tax_rate_calculate_ca_nb_tppt'] = $rule;

  // Rule component to calculate PST for QC
  $rule = rule($component_variable);
  $rule->label = t('Calculate QST QC');
  $rule->tags = array('Commerce Canadian Taxes', 'PST', 'QST', 'QC');
  $rule->weight = 15;
  $rule->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_qc_pst', array('line_item:select' => 'commerce-line-item'))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'country',
                                                            'value' => 'CA', ))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'administrative_area',
                                                            'value' => 'QC', ))
       ->action('commerce_tax_rate_apply', array(
          'commerce_line_item:select' => 'commerce-line-item',
          'tax_rate_name' => 'ca_qc_pst',
        ))
        ;
  $rules['commerce_tax_rate_calculate_ca_qc_pst'] = $rule;

  // Rule component to calculate HST for ON
  $rule = rule($component_variable);
  $rule->label = t('Calculate HST ON');
  $rule->tags = array('Commerce Canadian Taxes', 'HST', 'ON');
  $rule->weight = 1;
  $rule->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_on_hst', array('line_item:select' => 'commerce-line-item'))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'country',
                                                            'value' => 'CA', ))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'administrative_area',
                                                            'value' => 'ON', ))
       ->action('commerce_tax_rate_apply', array(
          'commerce_line_item:select' => 'commerce-line-item',
          'tax_rate_name' => 'ca_on_hst',
        ))
        ;
  $rules['commerce_tax_rate_calculate_ca_on_hst'] = $rule;

  // Rule component to calculate PST for MB
  $rule = rule($component_variable);
  $rule->label = t('Calculate RST MB');
  $rule->tags = array('Commerce Canadian Taxes', 'PST', 'RST', 'MB');
  $rule->weight = 15;
  $rule->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_mb_pst', array('line_item:select' => 'commerce-line-item'))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'country',
                                                            'value' => 'CA', ))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'administrative_area',
                                                            'value' => 'MB', ))
       ->action('commerce_tax_rate_apply', array(
          'commerce_line_item:select' => 'commerce-line-item',
          'tax_rate_name' => 'ca_mb_pst',
        ))
        ;
  $rules['commerce_tax_rate_calculate_ca_mb_pst'] = $rule;

  // Rule component to calculate PVT for MB
  $rule = rule($component_variable);
  $rule->label = t('Calculate PVT MB');
  $rule->tags = array('Commerce Canadian Taxes', 'PVT', 'MB', 'Provincial Vehicle Tax');
  $rule->weight = 1;
  $rule->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_mb_pvt', array('line_item:select' => 'commerce-line-item'))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'country',
                                                            'value' => 'CA', ))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'administrative_area',
                                                            'value' => 'MB', ))
       ->action('commerce_tax_rate_apply', array(
          'commerce_line_item:select' => 'commerce-line-item',
          'tax_rate_name' => 'ca_mb_pvt',
        ))
        ;
  $rules['commerce_tax_rate_calculate_ca_mb_pvt'] = $rule;

  // Rule component to calculate PST for SK
  $rule = rule($component_variable);
  $rule->label = t('Calculate PST SK');
  $rule->tags = array('Commerce Canadian Taxes', 'PST', 'SK');
  $rule->weight = 15;
  $rule->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_sk_pst', array('line_item:select' => 'commerce-line-item'))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'country',
                                                            'value' => 'CA', ))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'administrative_area',
                                                            'value' => 'SK', ))
       ->action('commerce_tax_rate_apply', array(
          'commerce_line_item:select' => 'commerce-line-item',
          'tax_rate_name' => 'ca_sk_pst',
        ))
        ;
  $rules['commerce_tax_rate_calculate_ca_sk_pst'] = $rule;

  // Rule component to calculate Liquor Consumption Tax for SK
  $rule = rule($component_variable);
  $rule->label = t('Calculate LCT SK');
  $rule->tags = array('Commerce Canadian Taxes', 'LCT', 'SK', 'Liquor Consumption Tax');
  $rule->weight = 15;
  $rule->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_sk_plt', array('line_item:select' => 'commerce-line-item'))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'country',
                                                            'value' => 'CA', ))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'administrative_area',
                                                            'value' => 'SK', ))
       ->action('commerce_tax_rate_apply', array(
          'commerce_line_item:select' => 'commerce-line-item',
          'tax_rate_name' => 'ca_sk_plt',
        ))
        ;
  $rules['commerce_tax_rate_calculate_ca_sk_plt'] = $rule;

  // Rule component to calculate PST for BC
  $rule = rule($component_variable);
  $rule->label = t('Calculate PST BC');
  $rule->tags = array('Commerce Canadian Taxes', 'PST', 'BC');
  $rule->weight = 15;
  $rule->condition(COMPONENT_NAME_PREFIX . 'rule_apply_ca_bc_pst', array('line_item:select' => 'commerce-line-item'))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'country',
                                                            'value' => 'CA', ))
       ->condition('commerce_order_compare_address', array('commerce_order:select' => 'commerce-line-item:order',
                                                            'address_field' => 'commerce_customer_billing|commerce_customer_address',
                                                            'address_component' => 'administrative_area',
                                                            'value' => 'BC', ))
       ->action('commerce_tax_rate_apply', array(
          'commerce_line_item:select' => 'commerce-line-item',
          'tax_rate_name' => 'ca_bc_pst',
        ))
        ;
  $rules['commerce_tax_rate_calculate_ca_bc_pst'] = $rule;

  return $rules;

} // commerce_canadian_taxes_default_rules_configuration()
